@@ -48,20 +48,22 @@ def make_events(num_events):
     for i in range(num_events):
         e = Event(kind=9999, content=secrets.token_hex(6), pubkey=pubkey, tags=tags)
         e.sign(prikey)
-        events.append(e)
+        events.append(dumps(["EVENT", e.to_json_object()]))
     return events
 
 
-async def adds_per_second(url, num_events=100):
-    relay = Relay(url)
+async def adds_per_second(url, num_events=200, id=None):
     events = make_events(num_events)
-    async with relay:
+    bytes_sent = 0
+    async with connect(url) as ws:
         with catchtime() as timer:
             for e in events:
-                await relay.add_event(e, check_response=True)
+                await ws.send(e)
+                bytes_sent += len(e)
+                response = await ws.recv()
                 timer += 1
     print(f"\tAdd: took {timer.duration:.2f} seconds. {timer.throughput():.1f}/sec")
-    return timer.throughput()
+    return timer.count, bytes_sent
 
 
 async def events_per_second(url, kind=9999, limit=500, duration=20, id=None, **kwargs):
@@ -77,7 +79,7 @@ async def events_per_second(url, kind=9999, limit=500, duration=20, id=None, **k
     print(
         f"\tEvents: took {timer.duration:.2f} seconds. {timer.throughput():.1f}/sec {bps:.1f}kBps"
     )
-    return timer.count, total_bytes
+    return timer.count * limit, total_bytes
 
 
 async def _make_requests(ws, query, limit, duration):
@@ -124,6 +126,13 @@ async def req_per_second(url, kind=9999, limit=50, duration=20, id=0):
     )
     return timer.count, total_bytes
 
+
+async def idle_conns(url, duration=20, id=None, **kwargs):
+    async with connect(url) as ws:
+        print(f"connected {id}")
+        await asyncio.sleep(duration)
+    return 0, 0
+
 async def runner(concurrency, func, *args, **kwargs):
     tasks = []
     start = perf_counter()
@@ -135,12 +144,18 @@ async def runner(concurrency, func, *args, **kwargs):
     duration = perf_counter() - start
     total_count = 0
     total_bytes = 0
+    num_connected = 0
     for r in results[0]:
-        count, received = r.result()
+        try:
+            count, received = r.result()
+        except Exception as e:
+            print(e)
+            continue
         total_count += count
         total_bytes += received
+        num_connected += 1
     total_bps = (total_bytes / duration) / (1024 * 1024)
     total_throughput = total_count / duration
     print(f"Total throughput: {total_throughput:.1f}/sec")
     print(f"Total MBps: {total_bps:.1f}MBps")
-
+    print(f"Total connected: {num_connected}/{concurrency}")
